<a href="http://www.kios.ucy.ac.cy"><img src="https://www.kios.ucy.ac.cy/wp-content/uploads/2021/07/Logotype-KIOS.svg" width="200" height="100"/><a>


EPANET Python Toolkit (EPyT) - Examples
=======================================

## Table of Contents

- [Examples](#examples)

## Examples

- [Toolkit Example 2:](./Toolkit_EX2_Hydrant_rating_curve.ipynb) Hydrant rating curve.
- [Toolkit Example 3:](./Toolkit_EX3_Minimum_chlorine_residual.ipynb) Minimum chlorine residual.
- [Toolkit Example 4:](./Toolkit_EX4_Network_Building.ipynb) Network building.
- [Example 1:](./EX1_Plot_network_topology.ipynb) Plot network topology.
- [Example 2:](./EX2_Hydraulic_analysis.ipynb) Hydraulic analysis.
- [Example 3:](./EX3_Quality_analysis.ipynb) Quality analysis.
- [Example 4:](./EX4_Plot_time_series.ipynb) Plot time series.
- [Example 5:](./EX5_Plot_values_parameters.ipynb) Load two inp files.
- [Example 6:](./EX6_load_two_inp_files.ipynb) Load two inp files.
- [Example 7:](./EX7_Set_Pump_Curves.ipynb) Set pump curves.
- [Example 9:](./EX9_compare_simulations.ipynb) Tanks to reservoirs.
- [Example 10:](./EX10_close_pipes_during_sim.ipynb) Close pipes during simulation.
- [Example 11:](./EX11_assing_new_curve_pump.ipynb) Assign a new curve to a pump.
- [Example 13:](./EX13c_add_cvpipe.ipynb) Add multiple control patterns.
- [Example 14:](./EX14_hydraulic_and_quality_analysis.ipynb) Hydraulic and Quality analysis.
- [Example 16:](./EX16_create_multiple_scenarios.ipynb) Create multiple scenarios.
- [Example 17b:](./EX17b_add_multiple_controls_pipestatus.ipynb) Add controls via normal functions.
- [Example 18:](./EX18_change_status_pipes.ipynb) Change status of pipe during simulation.
- [Example 20a:](./EX20a_external_controls.ipynb) Change of external Controls.
- [Example 20b:](./EX20b_external_controls.ipynb) Addition of external Controls.
- [Example 21:](./EX21_Pressure_driven_analysis_option.ipynb) Pressure driven analysis.
- [Example 22:](./EX22_Overflow_option_for_tanks.ipynb) Overflow of tanks.
- [Example 23:](./EX23_Change_connection_links.ipynb) Change connection of the links.
- [Example 24:](./EX24_delete_all_patterns.ipynb) Delete all patterns.
- [Example 25:](./EX25_set_node_name_ids.ipynb) Set node name IDs.
- [Plt Example 1:](./Plt_EX1_Create_Flow_gif.ipynb) Create a gif with the flows of Net1.
- [Plt Example 2:](./Plt_EX2_Create_Pressure_gif.ipynb) Create a gif with the pressure of net2-cl2.
- [API EN Example 1:](./Toolkit_api_EX1_using_EN_functions.ipynb) Create a network with EN functions, eliminitating the need to an EPANET formatted input file.
- [Example Export data:](./EX_to_excel_json.py) Use/Save results in different formats/types and files.

- &uparrow; [Back to top](#table-of-contents)
